.. include:: /substitutions.txt

.. _examples.diffractometer:

Diffractometer Examples
-----------------------

See also the documentation for the :ref:`geometries` module.

.. toctree::
   :maxdepth: 1
   :glob:

   notebooks/geo_*

.. rubric:: Downloads

Most examples are available as `Jupyter notebooks <https://jupyter.org/>`_ on
the |hklpy| source code website:
https://github.com/bluesky/hklpy/tree/main/docs/source/examples/notebooks
